@@ -75,7 +75,7 @@ void Object::setDescription(const QStringList &description)
 QVariantList Object::description() const
 {
     QVariantList list;
-    foreach (const QString &paragraph, m_description) {
+    for (const QString &paragraph : m_description) {
         list << paragraph;
     }
     return list;
